#!/bin/sh

SRCDIR=`pwd`
TEMP=`pwd`
VERSION=2.1.0
ROOT=repast.simphony
INSTALLATION=/opt/repast
ROOTA=$INSTALLATION/RepastTest2/MyModels
PLUGINS=$ROOTA/plugins
MANAGER=""

if [ "$1" = "" ]; then
	CRCip=$(/sbin/ip -o -4 addr list eth0 | awk '{print $4}' | cut -d/ -f1)
	java -jar $PLUGINS/portico.jar wanrouter --address $CRCip

else
	# Add to classpath

	CP=$CP:$PLUGINS/libs.bsf_$VERSION/lib/*:$PLUGINS/libs.ext_$VERSION/lib/*:$PLUGINS/$ROOT.batch_$VERSION/lib/*
	CP=$CP:$PLUGINS/$ROOT.batch_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.distributed.batch_$VERSION/lib/*
	CP=$CP:$PLUGINS/$ROOT.distributed.batch_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.core_$VERSION/lib/*
	CP=$CP:$PLUGINS/$ROOT.core_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.runtime_$VERSION/lib/*
	CP=$CP:$PLUGINS/$ROOT.runtime_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.data_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.dataLoader_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.scenario_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.essentials_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.groovy_$VERSION/bin
	CP=$CP:$PLUGINS/$ROOT.intergation_$VERSION/lib/*
	CP=$CP:$PLUGINS/$ROOT.intergation_$VERSION/bin
	CP=$CP:$PLUGINS/saf.core.ui_$VERSION/saf.core.v3d.jar
	CP=$CP:$PLUGINS/saf.core.ui_$VERSION/lib/*
	CP=$CP:$PLUGINS/libs/*
	CP=$CP:$PLUGINS/JoSQL-2.2.jar
	CP=$CP:$PLUGINS/jackson-all-1.9.0.jar
	CP=$CP:$PLUGINS/log4j-api-2.1.jar
	CP=$CP:$PLUGINS/portico.jar
	CP=$CP:$PLUGINS/log4j-core-2.1.jar

	now=$(date +"%D %T")
	echo "Current Date and Time : $now"

	if [ "$1" = "S" ]; then

# Code for Run on single Instance

		# Model directories
		MODELNAME=fManager
		MODEL_FOLDER=$ROOTA/$MODELNAME
		FILENAME=$SRCDIR/$MODELNAME/federateslist.txt


		if [ ! -e $SRCDIR/$MODELNAME.tar ]; then
			pwd
			ls -al
			echo "$MODELNAME not found"
			exit 1
		fi

		tar -xf $SRCDIR/$MODELNAME.tar

		mkdir $INSTALLATION/RepastTest2/$MODELNAME
		cp $SRCDIR/$MODELNAME/batch_params.xml $INSTALLATION/RepastTest2/$MODELNAME

		(cd $ROOTA;tar -xf $SRCDIR/$MODELNAME/model.tar)

		if [ ! -e $FILENAME ]; then
			pwd
			ls -al
			echo "federateslist.txt not found"
			exit 1
		fi

		cat $FILENAME | while read LINE
		do
			MODELNAME=$LINE
			MODEL_FOLDER=$ROOTA/$MODELNAME

			if [ ! -e $SRCDIR/$MODELNAME.tar ]; then
				pwd
				ls -al
				echo "$MODELNAME not found"
				exit 1
			fi

			tar -xf $SRCDIR/$MODELNAME.tar

			mkdir $INSTALLATION/RepastTest2/$MODELNAME
			cp $SRCDIR/$MODELNAME/batch_params.xml $INSTALLATION/RepastTest2/$MODELNAME

			(cd $ROOTA;tar -xf $SRCDIR/$MODELNAME/model.tar)

		done

		# Run
		Xvfb :0 -screen 1 1024x768x24 &
		sleep 15

		MODELNAME=fManager
		MODEL_FOLDER=$ROOTA/$MODELNAME

		CP=$CP:$MODEL_FOLDER/bin
		CP=$CP:$MODEL_FOLDER/src

		(cd $MODEL_FOLDER;java -cp $CP repast.simphony.runtime.RepastBatchMain -params "$INSTALLATION/RepastTest2/$MODELNAME/batch_params.xml" "$MODEL_FOLDER/$MODELNAME.rs") &

		cat $FILENAME | while read LINE
		do
			if [ "$MANAGER" = "" ]; then
		 		MANAGER=$LINE
				read LINE
			fi
		   
			MODELNAME=$LINE
			MODEL_FOLDER=$ROOTA/$MODELNAME

			CP=$CP:$MODEL_FOLDER/bin
			CP=$CP:$MODEL_FOLDER/src

			(cd $MODEL_FOLDER;java -cp $CP repast.simphony.runtime.RepastBatchMain -params "$INSTALLATION/RepastTest2/$MODELNAME/batch_params.xml" "$MODEL_FOLDER/$MODELNAME.rs") &
		done

		cat $FILENAME | while read LINE
		do
			if [ "$MANAGER" = "" ]; then
		 		MANAGER=$LINE
				MODELNAME=$LINE
				MODEL_FOLDER=$ROOTA/$MODELNAME

				CP=$CP:$MODEL_FOLDER/bin
				CP=$CP:$MODEL_FOLDER/src

				(cd $MODEL_FOLDER;java -cp $CP repast.simphony.runtime.RepastBatchMain -params "$INSTALLATION/RepastTest2/$MODELNAME/batch_params.xml" "$MODEL_FOLDER/$MODELNAME.rs")
		   fi
		done

		mkdir $SRCDIR/output
		cat $FILENAME | while read LINE
		do
			MODELNAME=$LINE
			MODEL_FOLDER=$ROOTA/$MODELNAME
		
			mkdir $SRCDIR/output/$MODELNAME
			cd $MODEL_FOLDER/output/
			if find . -mindepth 1 -print -quit | grep -q .; then
				cp $MODEL_FOLDER/output/* $SRCDIR/output/$MODELNAME
			fi
		done
		
			cd $SRCDIR
			tar -cf output.tar output

	else
		
# Code for Run on multiple Instances

		if [ ! -e $SRCDIR/batch_params.xml ]; then
			pwd
			ls -al
			echo "batch_params.xml not found"
			exit 1
		fi

		if [ ! -e $SRCDIR/model.tar ]; then
			pwd
			ls -al
			echo "model.tar not found"
			exit 1
		fi

		MODEL_NAME=`tar -tf $SRCDIR/model.tar | head -1 | awk -F'/' '{ print $1 }'`
		MODEL_FOLDER=$ROOTA/$MODEL_NAME

		CP=$CP:$MODEL_FOLDER/bin
		CP=$CP:$MODEL_FOLDER/src

		cp $SRCDIR/batch_params.xml $INSTALLATION/RepastTest2
		(cd $ROOTA;tar -xf $SRCDIR/model.tar)

		if [ -e $SRCDIR/input.tar ]; then
		    tar -xf $SRCDIR/input.tar

		    cp -r $SRCDIR/input $ROOTA/$MODEL_NAME
		fi

		if [ "$1" = "M" ]; then
			FILENAME=$SRCDIR/CRCip.txt
			if [ ! -e $FILENAME ]; then
				pwd
				ls -al
				echo "CRCip.txt not found"
				exit 1
			fi

			cat $FILENAME | while read LINE
			do
				if [ "$CRCip" = "" ]; then
				    CRCip=$LINE
					echo "portico.wan.enabled = true
portico.wan.router = $CRCip:23114" > $MODEL_FOLDER/RTI.rid
					echo "$CRCip"
				fi
			done
		else
			CRCip=$(cat $SRCDIR/batch_params.xml | grep -oP '(?=name="CRCip")[^<]+')
			CRCip=$(echo $CRCip | tr -d '/">')
			CRCip=$(echo $CRCip | tr -d '\r')
			NEW=""
			OLD="name=CRCip type=list value_type=string values="
			CRCip=$(echo $CRCip | sed "s/$OLD/$NEW/g")
						echo "portico.wan.enabled = true
portico.wan.router = $CRCip:23114" > $MODEL_FOLDER/RTI.rid
			echo "$CRCip"
		fi
		# Change directory to the model default

		cd $MODEL_FOLDER

		# Run

		java -cp $CP repast.simphony.runtime.RepastBatchMain -params "$INSTALLATION/RepastTest2/batch_params.xml" "$MODEL_FOLDER/$MODEL_NAME.rs"

		if [ $? -ne 0 ]; then
			echo "Exiting with error status"
			exit 1
		fi

		cd output
		tar -cf $TEMP/$MODEL_NAME.tar *

		cd $TEMP
		rm -rf $MODEL_FOLDER
	fi
fi

now=$(date +"%D %T")
echo "Current Date and Time : $now"

exit 0
